### Persefone.jl - a model of agricultural landscapes and ecosystems in Europe.
###
### Crop model comparison

using Dates
using DataFrames
using Logging
using LoggingExtras
using Persefone
using Random
using StableRNGs
using Test

const Ps = Persefone

import Unitful: @u_str, cm, m, km, ha, mg, g, kg, Length, Area, Mass
const m² = m^2
const km² = km^2
const ton = Persefone.AquaCropWrapper.ton

const PERSEFONE_DIR = joinpath(dirname(pathof(Persefone)), "..")

"""
    showfarmplots(model)

Show information about all the farmplots in the simulation and their
crop state.
"""
function showfarmplots(io::IO, model::Ps.SimulationModel)
    println(io, "Farmplots on $(model.date)")
    for (i, fp) in enumerate(model.farmplots)
        println(io, "$(fp.id): $(length(fp.pixels))px $(fp.soiltype) Farmer($(fp.farmer))")
    end
    return nothing
end
showfarmplots(model::Ps.SimulationModel) = showfarmplots(stdout, model)

"""
    inittestmodel(smallmap=true)

Initialise an SimulationModel for testing purposes.

`smallmap`: use a hypothetical small landscape rather than a real one?
"""
function inittestmodel(; xsize::Int=1,
                       ysize::Int=1,
                       start_date::Date = Date(2020, 01, 01),
                       end_date::Date = Date(2020, 12, 31),
                       weather_datapath::AbstractString=joinpath(PERSEFONE_DIR, "data/regions/jena/weather.csv"),
                       rng_seed::Int=42,
                       cropdir_almass::AbstractString=joinpath(PERSEFONE_DIR, "data/crops/almass/"),
                       cropdir_aquacrop::AbstractString=joinpath(PERSEFONE_DIR, "data/crops/aquacrop/")
                       )
    settings = Dict{String, Any}(
        "core.startdate" => start_date,
    )
    weather = Ps.initweather(weather_datapath, start_date, end_date)

    # crop types, with remapped names
    allcrops = Dict{String, Ps.AbstractCropType}()
    # ALMaSS crop types
    crops_almass = Ps.ALMaSS.readcropparameters(cropdir_almass)
    for (cropname, croptype) in crops_almass
        push!(allcrops, "ALMaSS/$(cropname)" => croptype)
    end
    # AquaCrop crop types
    crops_aquacrop = Ps.AquaCropWrapper.readcropparameters(cropdir_aquacrop)
    for (cropname, croptype) in crops_aquacrop
        if croptype.name != croptype.aquacrop_name
            push!(allcrops, "AquaCrop/$(cropname) {$(croptype.aquacrop_name)}" => croptype)
        else
            push!(allcrops, "AquaCrop/$(cropname)" => croptype)
        end
    end

    landscape = smalltestlandscape(xsize, ysize)

    model = AgricultureModel(;
        settings,
        rng = StableRNG(rng_seed),
        logger = global_logger(),
        date = start_date,
        landscape,
        weather,
        crops = allcrops
    )

    return model
end    

"""
    smalltestlandscape([xsize], [ysize])

Create a `xsize` x `ysize` landscape with agriculture landcover type.
"""
function smalltestlandscape(xsize::Int=8, ysize::Int=8)
    landscape = Matrix{Pixel}(undef, xsize, ysize)
    for x in 1:xsize, y in 1:ysize
        landscape[x,y] = Pixel(Ps.agriculture)
    end
    return landscape
end

function compare_cropmodels(; crops_compare::Vector{Tuple{String,String,Ps.AnnualDate}} = [
                                ("ALMaSS/maize", "AquaCrop/maize", Ps.AnnualDate(4, 15)),
                            ],
                            start_date = Date(2020, 01, 01),
                            end_date = Date(2020, 12, 31),
                            weather_datapath::AbstractString=joinpath(PERSEFONE_DIR, "data/regions/jena/weather.csv"),
                            rng_seed::Int=42,
                            cropdir_almass::AbstractString=joinpath(PERSEFONE_DIR, "data/crops/almass/"),
                            cropdir_aquacrop::AbstractString=joinpath(PERSEFONE_DIR, "data/crops/aquacrop/")
                            )
    allcrops = vcat(map(x -> x[1], crops_compare), map(x -> x[2], crops_compare))
    sowingdates = Dict{Ps.AnnualDate, Vector{String}}()
    for (almass_name, aquacrop_name, ad) in crops_compare
        if ! haskey(sowingdates, ad)
            sowingdates[ad] = String[]
        end
        push!(sowingdates[ad], almass_name)
        push!(sowingdates[ad], aquacrop_name)
    end
    @show sowingdates
    ncrops = length(allcrops)
    # Note: exclude Ps.nosoildata, Ps.nosoil
    allsoiltypes = filter(x -> x != Ps.nosoildata && x!= Ps.nosoil, instances(Ps.SoilType))
    nsoiltypes = length(allsoiltypes)
    model = inittestmodel(; xsize=ncrops, ysize=nsoiltypes,
                          start_date, end_date, weather_datapath,
                          rng_seed, cropdir_almass, cropdir_aquacrop)
    croptype_to_cropname = Dict(ct => cn for (cn, ct) in model.crops)
    @show length(model.farmplots)
    # create farmplots and crop states
    farmplot_id = 1
    farmer_id = 1
    for i in 1:ncrops
        cropname = "ALMaSS/natural grass"
        for j in 1:nsoiltypes
            # soiltype
            soiltype = allsoiltypes[j]
            model.landscape[i, j].soiltype = soiltype
            # farmplot, cropstate
            croptype = model.crops[cropname]
            cropstate = Ps.makecropstate(croptype, model, soiltype)
            pixels = [(i, j)]
            fp = FarmPlot(farmplot_id, pixels, farmer_id, soiltype, cropstate)
            push!(model.farmplots, fp)
            farmplot_id += 1
            farmer_id += 1
        end
    end
    # run simulation
    df_out_almass = DataFrame(:date => Date[], :farmplot_idx => Int[], :cropname => String[],
                              :height => typeof(1.0cm)[], :biomass => Float64[])
    df_out_aquacrop = DataFrame(:date => Date[], :farmplot_idx => Int[], :cropname => String[], :soiltype => Ps.SoilType[],
                                :height => typeof(1.0cm)[], :biomass => typeof(1.0*ton/ha)[])
    has_sowed = falses(length(model.farmplots))
    for day in start_date:end_date
        ad = Ps.AnnualDate(model.date)
        if haskey(sowingdates, ad)
            for cropname in sowingdates[ad]
                i = findfirst(==(cropname), allcrops)
                for j = 1:nsoiltypes
                    fp_idx = (i-1) * nsoiltypes + j
                    @info "Sowing \"$cropname\" on farmplot $fp_idx"
                    Ps.sow!(model.farmplots[fp_idx], model, cropname)
                    has_sowed[fp_idx] = true
                end
            end
            showfarmplots(model)
        end
        stepsimulation!(model)
        for (i, fp) in enumerate(model.farmplots)
            has_sowed[i] || continue
            croptype = Ps.croptype(fp)
            if croptype isa Ps.ALMaSS.CropType
                push!(df_out_almass, (; date=model.date, farmplot_idx=i, cropname=croptype_to_cropname[croptype],
                                      height=fp.cropstate.veg_height, biomass=fp.cropstate.veg_biomass))
            elseif croptype isa Ps.AquaCropWrapper.CropType
                height = cropheight(fp)
                biomass = fp.cropstate.cropstate.dayout.Biomass |> last
                push!(df_out_aquacrop, (; date=model.date, farmplot_idx=i,
                                        cropname=croptype_to_cropname[croptype], soiltype=fp.cropstate.soiltype,
                                        height, biomass))
            else
                error("Unknown crop type $(croptype(fp))")
            end
        end
    end
    @info "Simulated for $(end_date - start_date + Dates.Day(1))."
    return model, df_out_almass, df_out_aquacrop, sowingdates
end


function compare_cropmodels_summer(
    ; crops_compare::Vector{Tuple{String,String,Ps.AnnualDate}} = [
        ("ALMaSS/maize", "AquaCrop/maize", Ps.AnnualDate(4, 23)),
    ],
    year::Int = 2020,  # simulates January 1st to December 31st
    weather_datapath::AbstractString=joinpath(PERSEFONE_DIR, "data/regions/jena/weather.csv"),
    rng_seed::Int=42,
    cropdir_almass::AbstractString=joinpath(PERSEFONE_DIR, "data/crops/almass/"),
    cropdir_aquacrop::AbstractString=joinpath(PERSEFONE_DIR, "data/crops/aquacrop/")
    )
    return compare_cropmodels(; crops_compare, start_date=Date(year, 01, 01), end_date=Date(year, 12, 31),
                              weather_datapath, rng_seed, cropdir_almass, cropdir_aquacrop)
end

function compare_cropmodels_winter(
    ; crops_compare::Vector{Tuple{String,String,Ps.AnnualDate}} = [
        ("ALMaSS/winter wheat", "AquaCrop/winter wheat {wheatGDD}", Ps.AnnualDate(10, 23)),
        ("ALMaSS/winter rape", "AquaCrop/winter rape {rapeseed}", Ps.AnnualDate(8, 23)),
        ("ALMaSS/winter barley", "AquaCrop/winter barley {barleyGDD}", Ps.AnnualDate(9, 23)),
    ],
    year::Int = 2020,  # simulates from Date(year, 01, 01) to Date(year + 1, 12, 31)
    weather_datapath::AbstractString=joinpath(PERSEFONE_DIR, "data/regions/jena/weather.csv"),
    rng_seed::Int=42,
    cropdir_almass::AbstractString=joinpath(PERSEFONE_DIR, "data/crops/almass/"),
    cropdir_aquacrop::AbstractString=joinpath(PERSEFONE_DIR, "data/crops/aquacrop/")
    )
    return compare_cropmodels(; crops_compare, start_date=Date(year, 01, 01), end_date=Date(year + 1, 12, 31),
                              weather_datapath, rng_seed, cropdir_almass, cropdir_aquacrop)
end
